@@ -2,16 +2,15 @@ import inspect
 import multiprocessing as mp
 import re
 import sys
-import traceback
 import typing as t
 from contextlib import contextmanager
 from functools import partial
 from io import StringIO
 from pathlib import Path
 from traceback import format_exception
-from typing import Collection, List
 from warnings import warn
 
+import cv2 as cv
 import docstring_parser as dp
 import pandas as pd
 from pyqtgraph.Qt import QtWidgets, QtCore
@@ -19,8 +18,8 @@ from pyqtgraph.parametertree import Parameter, ParameterTree
 from ruamel.yaml import YAML, YAMLError
 from tqdm import tqdm
 
-from .typeoverloads import FilePath
 from .params.prjparam import PrjParam
+from .typeoverloads import FilePath
 
 yaml = YAML()
 
@@ -527,3 +526,27 @@ def popupFilePicker(parent=None, winTitle: str='', fileFilter: str='', existing=
     return fList[0]
   else:
     return None
+
+# Define at module level for mproc usage
+def _cvtImage(file, ext='png', replace=True):
+  if file.suffix[1:] == ext:
+    return
+  try:
+    cv.imwrite(str(file.with_suffix(f'.{ext}')), cv.imread(str(file)))
+    if replace:
+      file.unlink()
+  except Exception as ex:
+    return file, ex
+
+def convertImages(globstr:str='*.*', ext='png', replace=True, folder: FilePath=None):
+  if folder is None:
+    folder = Path()
+  folder = Path(folder)
+  files = list(folder.glob(globstr))
+  ret = mproc_apply(_cvtImage, files, 'Converting Files', extraArgs=(ext, replace))
+  errs = [f'{r[0].name}: {r[1]}' for r in ret if r is not None]
+  if errs:
+    print(
+      f'Conversion errors occurred in the following files:\n'
+      + '\n'.join(errs)
+    )
\ No newline at end of file
