@@ -518,7 +518,7 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
     if self.imgItem.qimage is None:
       return
     # Cheap way of splitting the int32 return value into uint8 RGBA
-    imColor = np.array([self.imgItem.qimage.pixel(*xyPos)], 'int32').view('uint8')
+    imColor = np.array([self.imgItem.qimage.pixel(*xyPos)], 'uint32').view('uint8')
     grayClr = np.mean(imColor[:3])
     fontColor = 'black' if grayClr > 127 else 'white'
     self.pxColorLbl.setStyleSheet(f'background:rgba{tuple(imColor)}; color:{fontColor}')
@@ -682,6 +682,7 @@ class MaskCompositor(ImageViewer):
 
     rec = pd.Series(newRecord, name=name)
     self._addRecord(rec, update)
+    return rec
 
   def _addRecord(self, rec: pd.Series, update=True):
     self.recordDf = self.recordDf.append(rec)
